package Acme::MetaSyntactic::calvin;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::calvin - Characters from Calvin and Hobbes

=head1 DESCRIPTION

Characters from the famous comic strip, I<Calvin and Hobbes>,
by I<Bill Watterson>. The comic ran from November 18th, 1985 till
December 31, 1995, 3150 strips in total.

See L<http://en.wikipedia.org/wiki/Calvin_and_Hobbes>.

=head1 QUOTE

    It's a magical world, Hobbes ol' buddy!
              Let's go exploring!

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-07-16 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.010.

=item *

2005-11-01

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Calvin Hobbes
Mom Dad 
Susie_Derkins Miss_Wormwood Rosalyn Moe
Principal_Spittle Uncle_Max Mr_Lockjaw
Galaxoid Nebular
Stupendous_Man Spaceman_Spiff Tracer_Bullet Captain_Napalm God
