package Acme::MetaSyntactic::abba;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::abba - Singers from the 1970s Swedish pop group

=head1 DESCRIPTION

ABBA won the 1974 Eurovision Songfestival for Sweden, which started
their very successful international career that would last into the
early 1980s.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-11-01

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Anni_Frid_Lyngstad Bjorn_Ulvaeus Benny_Andersson Agnetha_Faltskog
