package Acme::MetaSyntactic::smurfs;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::smurfs - Smurfs

=head1 DESCRIPTION

Various of the smurfs (and supporting characters).

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-07-23 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.011.

=item *

2006-05-16

Theme proposed independently by Flavio Poletti.

=item *

2005-11-01

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Airborne Alchemist Baby Baker Balthazar Bashful Brainy Clockwork
Clumsy Dabbler Doc Dopey Dreamy Farmer Finance Fisher Gargamel
Grandpa Greedy Grouchy Handy Harmony Hefty Johan Jokey King Miner
Nanny Nat Nosey Painter Papa Poet Princess_Salvina Reflection
Sassette Scaredy Sleepy Sloppy Slouchy Smoogle Smurfette Sneezy
Sweepy Tailor Timid Tracker Vanity Weakling Wild Wooley
