package Acme::MetaSyntactic::nis;
use strict;
use Acme::MetaSyntactic::MultiList;
our @ISA = qw( Acme::MetaSyntactic::MultiList );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::nis - Nick Ing-Simmons

=head1 DESCRIPTION

Nick Ing-Simmons passed away on 25 September 2006. This is his theme.

The sad annoucement:
L<http://www.nntp.perl.org/group/perl.perl5.porters/116654>.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-10-02

Introduced in Acme-MetaSyntactic version 0.94.

=item *

2006-09-27

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::MultiList>.

=cut

__DATA__
# default
nick
# names nick
Nick Ing_Simmons NI_S pumpking perl5003_02 Tk PerlTk
# names modules
Audio Bundle_Tk Devel_Leak File_Compare Make Math_GSL Math_Rand48
PodToHTML Ptty Regexp Sys_Sysconf Tk Tk_HTML Tk_JPEG Tk_PNG
