package Acme::MetaSyntactic::scooby_doo;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::scooby_doo - The Scooby Doo theme

=head1 DESCRIPTION

Characters from the Scooby-Doo serial.

=head1 CONTRIBUTOR

Michel Rodriguez

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-06-12

Introduced in Acme-MetaSyntactic version 0.78.

=item *

2005-01-16

List proposed by Michel Rodriguez.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en
# names en
Scooby_Doo Shaggy Daphne Velma Freddy Scrappy_Doo Scooby_Dum   Scooby_Dee
# names fr
Scooby_Doo Sammy Daphne  Vera  Fred   Scrappy_Doo Oncle_Scooby

