package Acme::MetaSyntactic::dwarves;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.002';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::dwarves - The seven dwarves theme

=head1 DESCRIPTION

Snow-White seven dwarves.

=head1 CONTRIBUTORS

Antoine Hulin, Abigail, Xavier Caron.

=head1 CHANGES

=over 4

=item *

2013-12-09 - v1.002

Updated to fix a misspelling in Bashful's name (English),
in Acme-MetaSyntactic-Themes version 1.038.

=item *

2012-05-14 - v1.001

Updated by Abigail (added Irish Gaelic and Croatian)
in Acme-MetaSyntactic-Themes version 1.001.

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-05-15

Updated by Abigail (added Danish, German, Spanish, Finnish, Hungarian,
Italian, Norwegian, Portuguese and Swedish) in Acme-MetaSyntactic version 0.74.

=item *

2005-11-14

Introduced in Acme-MetaSyntactic version 0.48.

=item *

2005-10-28

English and French lists proposed by Xavier Caron.

I definitely I<had> to include this list! C<:-)>

=item *

2005-10-23

Submitted as a simple list of English names by Abigail.

=item *

2005-01-30

Initial lists (French and English) proposed by Antoine Hulin.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en
# names da
Brille     Lystig      Gnavpot     Dumpe       Sovnig      Prosit      Flovmand
# names de
Chef       Happy       Brummbar    Seppl       Schlafmutz  Hatschi     Pimpel
# names en
Doc        Happy       Grumpy      Dopey       Sleepy      Sneezy      Bashful
# names es
Sabio      Feliz       Grunon      Tontin      Dormilon    Alergico    Romantico
# names fi
Viisas     Lystikas    Joro        Vilkas      Unelias     Nuhanena    Ujo
# names fr
Prof       Joyeux      Grincheux   Simplet     Dormeur     Atchoum     Timide
# names ga
Saoi       Sonai       Cancran     Simpleoir   Codlatan    Sraothachan Cuthalachan
# names hr
Uco        Srecko      Ljutko      Glupko      Pospanko    Kihavko     Stidljivko
# names hu
Tudor      Vidor       Morgo       Kuka        Szundi      Hapci       Szende
# names it
Dotto      Gongolo     Brontolo    Cucciolo    Pisolo      Eolo        Mammolo
# names no
Brille     Lystig      Sinnataggen Minsten     Sovnig      Prosit      Blygen
# names pt
Mestre     Feliz       Zangado     Dunga       Soneca      Atchim      Dengoso
# names sv
Kloker     Glader      Butter      Toker       Trotter     Prosit      Blyger
