package Acme::MetaSyntactic::lucky_luke;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::lucky_luke - Characters from I<Lucky Luke>

=head1 DESCRIPTION

Characters from the comic I<Lucky Luke>, by Morris et. al.

=head1 BUGS

This list isn't complete.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-08-06 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.013.

=item *

2005-10-27

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Lucky_Luke Jolly_Jumper Rantanplan
Ma_Dalton Joe_Dalton William_Dalton Jack_Dalton Averell_Dalton
Calamity_Jane Billy_the_Kid Judge_Roy_Bean Jesse_James
