package Acme::MetaSyntactic::groo;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::groo - The Groo the Wanderer theme

=head1 DESCRIPTION

A list of characters from the I<Groo the Wanderer> long-running
comic-book authored by Sergio Aragonès and Mark Evanier.

If you are interested in Groo, you should have a look at
L<http://www.groo.com/>, L<http://www.povonline.com/> and
L<http://www.sergioaragones.com/>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

=head1 CHANGES

=over 4

=item *

2012-05-14 - v1.001

Updated with an C<=encoding> pod command in version 1.001.

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-07-10

Corrected a typo in Acme-MetaSyntactic version 0.82.

=item *

2005-06-21

Introduced in Acme-MetaSyntactic version 0.27.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Groo Rufferto Sage Chakaal Minstrel Grooella Arba Dakarba Arcadio
Taranto Pal Drumm Mulch Scribe Weaver Gravito Granny_Groo Pipil_Khan
The_Witch_of_Kaan Captain_Ahax
