package Acme::MetaSyntactic::summerwine;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::summerwine - The 'Last of the Summer Wine' theme

=head1 DESCRIPTION

Characters in I<Last of the Summer Wine>, the longest-running sitcom in the
world.  Only the 'main' name by which each character is addressed is used
(nickname, Christian name, or surname depending on the character) so that they
make better identifiers.

=head1 CONTRIBUTOR

Smylers, who paid £42 for the privilege at the YAPC Europe 2006 auction
in Birmingham.

This theme was chosen because I<Last of the Summer Wine> is set in Smylers's
home town of Holmfirth (in West Yorkshire in the UK), the main character names
are quite fun to use as identifiers, and it was an unlikely theme to be
included otherwise.  Having minor characters called 'Pearl' and 'Smiler' is a
bonus.

=head1 CHANGES

=over 4

=item *

2012-05-14 - v1.001

Updated with an C<=encoding> pod command
in Acme-MetaSyntactic-Themes version 1.001.

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-11-06

Introduced in Acme-MetaSyntactic version 0.99.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
compo
clegg
foggy
seymour
truly
nora
ivy
sid
wally
wesley
crusher
howard
pearl
marina
edie
glenda
barry
eli
auntie
smiler
billy
roz
tom
entwistle
alvin
nellie
