package Acme::MetaSyntactic::reindeer;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::reindeer - Santa's Reindeer

=head1 DESCRIPTION

The names of Santa's Reindeer. Note spelling variations exists, and
the inclusion of Rudolf is doubtful.

See L<https://en.wikipedia.org/wiki/Santa_Claus%27s_reindeer>

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-21 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.002.

=item *

2005-10-24

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
dasher dancer prancer vixen comet
cupid donner blitzen rudolf
