package Acme::MetaSyntactic::gems;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::gems - The gem stones theme

=head1 DESCRIPTION

A list of gem stones, as given by
L<http://http://en.wikipedia.org/wiki/Gemstone>.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-07

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-02-06

Introduced in Acme-MetaSyntactic version 0.60.

=item *

2005-10-27

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
agate alexandrite amber amethyst ammolite andalusite aquamarine axinite
benitoite beryl bone cassiterite chrysoberyl chrysocolla chrysoprase
citrine clinohumite coral diamond emerald feldspar garnet girasol hematite
iolite ivory jade jadeite jasper jet kornerupine kunzite lapis_lazuli
lignite malachite moonstone mother_of_pearl nephrite obsidian olivine
opal pearl peridot pyrite quartz ruby sapphire spinel sugilite tanzanite
tiger_s_eye topaz tortoiseshell tourmaline turquoise zircon zoisite
