package Acme::MetaSyntactic::monty_spam;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::monty_spam - The Monty Python SPAM theme

=head1 DESCRIPTION

The breakfast of champions: I<egg and bacon; egg,
sausage, and bacon; egg and SPAM; egg, bacon, and SPAM; egg, bacon,
sausage and SPAM; SPAM, bacon, sausage, and SPAM; SPAM, egg, SPAM, SPAM,
bacon, and SPAM; SPAM, SPAM, SPAM, egg, and SPAM; SPAM, SPAM, SPAM,
SPAM, SPAM, SPAM, baked beans, SPAM, SPAM, SPAM, and SPAM; or lobster
thermidor aux crevettes with a mornay sauce garnished with truffle pate,
brandy, and a fried egg on top and SPAM.>

List taken from the Monthy Python spam sketch, available at
L<http://www.cusd.claremont.edu/~mrosenbl/spamfiction.html#mp>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat, inspired by Ricardo Signes.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-07-18

Introduced in Acme-MetaSyntactic version 0.31.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
bacon
baked_beans
egg
egg_and_bacon
egg_and_SPAM
egg_bacon_and_SPAM
egg_bacon_sausage_and_SPAM
egg_bacon_SPAM_and_sausage
egg_bacon_SPAM_and_sausage_without_the_SPAM
egg_sausage_and_bacon
eggs
historian
lobster_thermidor_aux_crevettes_with_a_mornay_sauce_garnished_with_truffle_pate_brandy_and_a_fried_egg_on_top_and_SPAM
lovely_SPAM
Mr_Bun
Mrs_Bun
policeman
SPAM
SPAM_bacon_sausage_and_SPAM
SPAM_egg_sausage_and_SPAM
SPAM_egg_SPAM_SPAM_bacon_and_SPAM
SPAM_SPAM_SPAM_egg_and_SPAM
SPAM_SPAM_SPAM_SPAM_SPAM_SPAM_baked_beans_SPAM_SPAM_SPAM_and_SPAM
the_Green_Midget_cafe_at_Bromley
the_Hungarian
tomato
vikings
waitress
wonderful_SPAM
