package Acme::MetaSyntactic::screw_drives;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::screw - The screw drives theme

=head1 DESCRIPTION

This theme lists different screw drive types.

See L<https://en.wikipedia.org/wiki/Screw_drive>.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-09-17 - v1.000

Expanded the list thanks to Wikipedia,
and published in Acme-MetaSyntactic-Themes version 1.019.

=item *

2006-05-13

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
square
hex
pentagon
thumbscrew
slot
cross cross_recess
Phillips
Frearson Reed_and_Prince
French_recess BNAE_NFL22_070
JIS_B_1012
Mortorq
Pozidriv
Supadriv
Robertson Scrulox
hex_socket Allen
hexalobular_socket Torx star_drive
TTAP
Phillips_square Quadrex Deck_Mate
breakaway_head
Bristol
clutch clutch_type_A clutch_type_G
claw
double_hex
line ALR2 ALR3 ALR4 ALR5 ALR6 ALH2 ALH3 ALH4 ALH5 ALH6 ALR3T
one_way
pentalobe
polydrive
spanner snake_eyes
spline
Torq_set
TA
TP3
tri_wing triangular_slotted tri_groove Opsit
Triple_square XZN
protruding_obstacle
