package Acme::MetaSyntactic::pantagruel;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::pantagruel - The Pantagruel theme

=head1 DESCRIPTION

Pantagruel's genealogy.

List taken from I<Pantagruel>, chapter 2, by Maistre Françoys Rabelais.

=head1 CONTRIBUTOR

Rafael Garcia-Suarez

=head1 CHANGES

=over 4

=item *

2012-05-14 - v1.001

Updated with an C<=encoding> pod command in version 1.001.

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-05-01

Introduced in Acme-MetaSyntactic version 0.72.

=item *

2006-03-23

Initial list proposed by Rafaël Garcia-Suarez.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Chalbroth
Sarabroth
Faribroth
Hurtaly
Nembroth
Athlas
Goliath
Eryx
Titius
Eryon
Polyphemus
Cacus
Etion
Enceladus
Ceus
Typhoeus
Aloeus
Othus
Aegeon
Briareus
Porphyrio
Adamastor
Anteus
Agatho
Porus
Aranthas
Gabbara
Goliath_de_Secundille
Offot
Artachees
Oromedon
Gemmagog
Sisyphus
Hercules
Enay
Fierabras
Morguan
Fracassus
Ferragus
Happemousche
Bolivorax
Longys
Gayoffe
Maschefain
Brulefer
Engoulevent
Galehaut
Myrelangault
Galaffre
Falourdin
Roboastre
Sortibrant_de_Conimbres
Brushant_de_Mommiere
Bruyer
Mabrun
Foutasnon
Hacquelebac
Vitdegrain
Grantgousier
Gargantua
Pantagruel
