package Acme::MetaSyntactic::garfield;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::garfield - The Garfield theme

=head1 DESCRIPTION

Characters from the comic I<Garfield>, by Jim Davis. First appeared
on June 19, 1978, and still running today. Garfield appears in, or
has appeared in, over 2500 newspapers.

This list does not include characters which only appeared in the
television shows. This may be a bug.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-07

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-02-20

Introduced in Acme-MetaSyntactic version 0.62.

=item *

2005-10-27

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Garfield Odie Jon_Arbuckle
Arlene Pooky Nermal Mom Dad Doc_Boy Grandma Lyman Irma Liz
Herman_Post Hubert Rea Ellen Caped_Avenger 
Squeak Floyd Guido Clive Stretch
Second_Helping Sushi
