package Acme::MetaSyntactic::afke;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::afke - Afke's Children

=head1 DESCRIPTION

I<Afke's tiental> (I<Afkes ten>) is a classic Dutch childrens book,
describing the life of the ten children of Afke. This package supplies
the ten names.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-28 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.003.

=item *

2005-10-24

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
eeltje watse klaas jetse jouke
wiepkje sietske boukje wiebe sipke
