package Acme::MetaSyntactic::buffy;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::buffy - The Buffy theme

=head1 DESCRIPTION

The characters from London.pm's favorite serial.
Courtesy of L<http://buffyology.johnhorner.nu/>.

=head1 CONTRIBUTOR

Rafael Garcia-Suarez.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-05-31

Mail from John Horner informing of the new address of the buffyology web site.

=item *

2005-02-07

Introduced in Acme-MetaSyntactic version 0.09.

=item *

2005-02-04

List proposed by Rafaël Garcia-Suarez.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Adam Angel Anya Buffy Cordelia Darla Dawn Drusilla Faith Giles Glory
Jenny Jonathan Joyce Kendra Oz Snyder Prof_Walsh Riley Spike Tara
The_Master The_Mayor Warren Wesley Willow Xander
