package Acme::MetaSyntactic::teletubbies;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::teletubbies - The teletubbies theme

=head1 DESCRIPTION

Over the hills and far away, Teletubbies come to play.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

=head1 ACKNOWLEDGMENT
 
Thanks to Jérôme Fenal, for inspiration over IRC.

=head1 CHANGES

=over 4

=item *

2012-05-14 - v1.001

Updated with an C<=encoding> pod command
in Acme-MetaSyntactic-Themes version 1.001.

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-05-23

Introduced in Acme-MetaSyntactic version 0.23.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Tinky_Winky Dipsy Laa_Laa Po
Noo_Noo Trumpets Baby_Sun Narrator
