package Acme::MetaSyntactic::care_bears;
use strict;
use Acme::MetaSyntactic::MultiList;
our @ISA = qw( Acme::MetaSyntactic::MultiList );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::care_bears - The Care Bears theme

=head1 DESCRIPTION

The Care Bears are characters created by American Greetings in the 1980s
for use on greeting cards. Later on, they got turned into plush teddy
bears, and got their own television series.

Official website: L<http://www.care-bears.com/>.

=head1 CONTRIBUTORS

Éric Cassagnard, Philippe Bruhat.

=head1 CHANGES

=over 4

=item *

2012-11-12 - v1.000

Published in Acme-MetaSyntactic-Themes version 1.027.

=item *

2012-10-23

Collected the list from
L<http://en.wikipedia.org/wiki/List_of_Care_Bear_characters>.
Another possible source would be
L<http://carebears.wikia.com/wiki/List_Of_Care_Bear_Characters>.

=item *

2006-07-13

Idea submitted by Éric Cassagnard.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::MultiList>.

=cut

__DATA__
# names original
Bedtime_Bear
Birthday_Bear
Cheer_Bear
Friend_Bear
Funshine_Bear
Good_Luck_Bear
Grumpy_Bear
Love_a_Lot_Bear
Tenderheart_Bear
Wish_Bear
# names 1980s_1990s
Baby_Hugs_Bear
Baby_Tugs_Bear
Champ_Bear
Daydream_Bear
Forest_Friend_Bear
Grams_Bear
Harmony_Bear
I_Love_You_Bear
Perfect_and_Polite_Panda
Sea_Friend_Bear
Secret_Bear
Share_Bear
Surprise_Bear
Take_Care_Bear
True_Heart_Bear
# names 2000s
America_Cares_Bear
Bashful_Heart_Bear
Best_Friend_Bear
Do_Your_Best_Bear
Laugh_a_Lot_Bear
Smart_Heart_Bear
Thanks_a_Lot_Bear
Hopeful_Heart_Bear
All_My_Heart_Bear
Amigo_Bear
Heartsong_Bear
Play_a_Lot_Bear
Shine_Bright_Bear
Superstar_Bear
Work_of_Heart_Bear
Sweet_Dreams_Bear
Always_There_Bear
Oopsy_Bear
Pink_Power_Bear
Sweet_Sakura_Bear
# names 2010s
Wonderheart_Bear
Great_Giving_Bear
# names movie
Me_Bear
Messy_Bear
Too_Loud_Bear
# names cousins
Brave_Heart_Lion
Bright_Heart_Raccoon
Cozy_Heart_Penguin
Gentle_Heart_Lamb
Lotsa_Heart_Elephant
Loyal_Heart_Dog
Noble_Heart_Horse
Playful_Heart_Monkey
Proud_Heart_Cat
Swift_Heart_Rabbit
Treat_Heart_Pig
