package Acme::MetaSyntactic::contrade;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::contrade - The contrade theme

=head1 DESCRIPTION

The most well-known contrade (districts within an Italian city) are
probably the 17 that race in the Palio di Siena.

=head1 CONTRIBUTOR

Estelle Souche

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-03-13

Introduced in Acme-MetaSyntactic version 0.65.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Aquila 
Bruco 
Chiocciola 
Civetta 
Drago 
Giraffa 
Istrice 
Leocorno 
Lupa 
Nicchio 
Oca 
Onda 
Pantera 
Selva 
Tartuca 
Torre 
Valdimontone 
