package Acme::MetaSyntactic::mars;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::mars - The mars theme

=head1 DESCRIPTION

This theme provides the list of the names of planet Mars,
as they appear in Kim Stanley Robinson's I<Mars> trigoly.

=head1 CONTRIBUTOR

Laurent Gautrot.

=head1 CHANGES

=over 4

=item *

2012-07-31 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.012
(published one day late).

=item *

2006-05-31

List proposed by Laurent Gautrot.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Al_Qahira
Ares
Auqakuh
Bahram
Harmakhis
Hrad
Huo_Hsing
Kasei
Ma_adim
Maja
Mamers
Mangala
Mars
Mawrth
Nirgal
Shalbatanu
Simud
Tiu
