package Acme::MetaSyntactic::constellations;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::constellations - The constellations theme

=head1 DESCRIPTION

The 88 modern constellations.

List taken from
L<http://en.wikipedia.org/wiki/List_of_stars_by_constellation>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-10-17

Introduced in Acme-MetaSyntactic version 0.44.

=item *

2005-08-24

The IRC conversation that lead to L<Acme::MetaSyntactic::stars>
inevitably lead to this theme also.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Andromeda Antlia Apus Aquarius Aquila Ara Aries Auriga Bootes Caelum
Camelopardalis Cancer Canes_Venatici Canis_Major Canis_Minor Capricornus
Carina Cassiopeia Centaurus Cepheus Cetus Chamaeleon Circinus Columba
Coma_Berenices Corona_Australis Corona_Borealis Corvus Crater Crux Cygnus
Delphinus Dorado Draco Equuleus Eridanus Fornax Gemini Grus Hercules
Horologium Hydra Hydrus Indus Lacerta Leo Leo_Minor Lepus Libra Lupus
Lynx Lyra Mensa Microscopium Monoceros Musca Norma Octans Ophiuchus Orion
Pavo Pegasus Perseus Phoenix Pictor Pisces Piscis_Austrinus Puppis Pyxis
Reticulum Sagitta Sagittarius Scorpius Sculptor Scutum Serpens Sextans
Taurus Telescopium Triangulum Triangulum_Australe Tucana Ursa_Major
Ursa_Minor Vela Virgo Volans Vulpecula
