package Acme::MetaSyntactic::pie;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pie - The pie theme

=head1 DESCRIPTION

A list of English pies.

"Isle of Skye" is, apparently cockney rhyming slang for pie.

=head1 CONTRIBUTOR

Nicholas Clark

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-08-07

Introduced in Acme-MetaSyntactic version 0.86.

=item *

2005-11-28

List proposed by Nicholas Clark.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
apple
cherry
mince
steak_and_kidney
chicken_and_mushroom
beef_and_ale
pumpkin
lemon_merengue
pecan
Isle_of_Skye
