package Acme::MetaSyntactic::facecards;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::facecards - The facecards theme

=head1 DESCRIPTION

The traditional names of face cards in French playing cards.

=head1 CONTRIBUTOR

Estelle Souche.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-11-07

Introduced in Acme-MetaSyntactic version 0.47.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Charles   Judith Lahire
Cesar     Rachel Hector
David     Pallas Ogier
Alexandre Argine Lancelot

