package Acme::MetaSyntactic::camelidae;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::camelidae - Members of the Camelidae family

=head1 DESCRIPTION

The Perl community's favourite animals.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-06-25 - v1.000

Published in Acme-MetaSyntactic-Themes version 1.007

=item *

2005-11-01

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
llama alpaca guanaco vicuna dromedary bactrian_camel
